/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "UCQDetails.h"

/**
 * \brief Sets up the GUI and stores the tableModel.
 *
 * \param parent Pointer to the parent QWidget.
 * \param tableModel Pointer to the instance of TableModel that contains the
 *        letters to show.
 */
UCQDetails::UCQDetails ( QWidget* parent, TableModel* tableModel ) :
    QWidget ( parent, Qt::SplashScreen )
{
    ui_.setupUi ( this );
    tableModel_ = tableModel;
    ui_.label->setAlignment(Qt::AlignCenter);
}

/**
 * \brief Method that prepares the widget and makes it visible at the mouse
 *        cursor position.
 *
 * \param e MouseEvent that triggered the widget.
 */
void UCQDetails::changeStatus ( QMouseEvent* e )
{
    setGeometry ( e->globalX (), e->globalY (), width (), height () );
    show ();
}

/**
 * \brief Updates the GUI to show the new letter.
 *
 * \param index Index of the letter to display.
 * \see TableModel::getVisibleLetter()
 */
void UCQDetails::changeLetter ( QModelIndex index )
{
    prepareLabels ( tableModel_->getVisibleLetter ( index ) );
}

/**
 * \brief Method to move the widget to a new screen position.
 *
 * \param x X coordinate to move to.
 * \param y Y coordinate to move to.
 */
void UCQDetails::move ( int x, int y )
{
    setGeometry ( x, y, width (), height () );
}

/**
 * \brief Collects the desired information from the letter and displays it on
 *        the GUI.
 *
 * \param letter The letter that should be displayed on the widget.
 */
void UCQDetails::prepareLabels ( Letter* letter )
{
    QList<uint> cp = letter->getCodepoint();
    QString text = " ";

    for ( int i = 0; i < cp.size (); ++i ) {
        if(i > 0){
            text.append(" + ");
        }
        text.append(UCTools::unicodeToString(cp.at ( i )));
    }
    text.append(" ");
    ui_.label->setText ( text );
    ui_.blockLabel->setText ( letter->getBlock () );
    ui_.infoLabel->setText ( tr ( "Version:" ) +" " + letter->getVersionInfo () );
    adjustSize ();
}

/**
 * \brief Setter for the tableModel.
 *
 * \param tableModel The instance of TableModel that contains the letters to
 *                   show.
 *
 */
void UCQDetails::setTableModel ( TableModel* tableModel )
{
    this->tableModel_ = tableModel;
}

/**
 * \brief Sets the font with pointsize 60.
 *
 * \param font The font in which the letters should be displayed.
 */
void UCQDetails::setFont(const QFont& font){
    QFont f(font);
	f.setPointSize(60);
	ui_.label->setFont(f);
}
